# pyleafpro 
Módulo para exemplificar construção de projetos python do curso pytools

Nesse curso é ensinado como contribuir com projetos de código aberto

link para curso [python pro](https://www.python.pro.br/curso-de-python-gratis)

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/pouster-audio/pyleafpro/Python%20application)
[![Updates](https://pyup.io/repos/github/Pouster-audio/pyleafpro/shield.svg)](https://pyup.io/repos/github/Pouster-audio/pyleafpro/)
[![Python 3](https://pyup.io/repos/github/Pouster-audio/pyleafpro/python-3-shield.svg)](https://pyup.io/repos/github/Pouster-audio/pyleafpro/)

suportada versão 3 de python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:

```console
flake8

```

tópicos a serem abordados:
  1.Git
  2.virtualenv
  3.Pip
